@@ -29,7 +29,7 @@ from sklearn.utils.extmath import stable_cumsum
 from scipy.sparse import issparse
 
 import daal4py
-from .._utils import getFPType, method_uses_sklearn, method_uses_daal
+from .._utils import getFPType, get_patch_message
 import logging
 
 
@@ -92,7 +92,7 @@ def _n_components_from_fraction(explained_variance_ratio, frac):
     return n_components
     
 
-def _fit_full(self, X, n_components):
+def _fit_full_prev(self, X, n_components):
     """Fit the model by computing full SVD on X"""
     n_samples, n_features = X.shape
 
@@ -142,8 +142,6 @@ def _fit_full(self, X, n_components):
     return U, S, V
 
 
-_fit_full_copy = _fit_full
-
 class PCA_prev(PCA_original):
     __doc__ = PCA_original.__doc__
 
@@ -159,7 +157,7 @@ class PCA_prev(PCA_original):
         self.random_state = random_state
 
     def _fit_full(self, X, n_components):
-        return _fit_full_copy(self, X, n_components)
+        return _fit_full_prev(self, X, n_components)
 
 
 class PCA(PCA_original):
@@ -354,11 +352,10 @@ class PCA(PCA_original):
         _validate_n_components(n_components, n_samples, n_features)
 
         if n_samples > n_features and (X.dtype == np.float64 or X.dtype == np.float32):
-            logging.info("sklearn.decomposition.PCA.fit: " + method_uses_daal)
+            logging.info("sklearn.decomposition.PCA.fit: " + get_patch_message("daal"))
             return self._fit_full_daal4py(X, n_components)
-        else:
-            logging.info("sklearn.decomposition.PCA.fit: " + method_uses_sklearn)
-            return self._fit_full_vanilla(X, n_components)
+        logging.info("sklearn.decomposition.PCA.fit: " + get_patch_message("sklearn"))
+        return self._fit_full_vanilla(X, n_components)
 
 
     def _fit(self, X):
@@ -393,16 +390,15 @@ class PCA(PCA_original):
         if self._fit_svd_solver == 'full':
             return self._fit_full(X, n_components)
         elif self._fit_svd_solver in ['arpack', 'randomized']:
-            logging.info("sklearn.decomposition.PCA.fit: " + method_uses_sklearn)
+            logging.info("sklearn.decomposition.PCA.fit: " + get_patch_message("sklearn"))
             return self._fit_truncated(X, n_components, self._fit_svd_solver)
         elif self._fit_svd_solver == 'daal':
             if X.shape[0] < X.shape[1]:
                 raise ValueError("svd_solver='daal' is applicable for tall and skinny inputs only.")
-            logging.info("sklearn.decomposition.PCA.fit: " + method_uses_daal)
+            logging.info("sklearn.decomposition.PCA.fit: " + get_patch_message("daal"))
             return self._fit_daal4py(X, n_components)
-        else:
-            raise ValueError("Unrecognized svd_solver='{0}'"
-                             "".format(self._fit_svd_solver))
+        raise ValueError("Unrecognized svd_solver='{0}'"
+                         "".format(self._fit_svd_solver))
 
 
     def fit_transform(self, X, y=None):
@@ -426,26 +422,24 @@ class PCA(PCA_original):
             # Handle n_components==None
             n_components = _process_n_components_None(
                 self.n_components, self.svd_solver, X.shape)
-            logging.info("sklearn.decomposition.PCA.fit: " + method_uses_daal)
+            logging.info("sklearn.decomposition.PCA.fit: " + get_patch_message("daal"))
             self._fit_daal4py(X, n_components)
-            logging.info("sklearn.decomposition.PCA.transform: " + method_uses_daal)
+            logging.info("sklearn.decomposition.PCA.transform: " + get_patch_message("daal"))
             if self.n_components_ > 0:
                 return self._transform_daal4py(X, whiten=self.whiten, check_X=False)
-            else:
-                return np.empty((self.n_samples_, 0), dtype=X.dtype)
+            return np.empty((self.n_samples_, 0), dtype=X.dtype)
+        U, S, V = self._fit(X)
+        U = U[:, :self.n_components_]
+
+        logging.info("sklearn.decomposition.PCA.transform: " + get_patch_message("sklearn"))
+        if self.whiten:
+            # X_new = X * V / S * sqrt(n_samples) = U * sqrt(n_samples)
+            U *= np.sqrt(X.shape[0] - 1)
         else:
-            U, S, V = self._fit(X)
-            U = U[:, :self.n_components_]
+            # X_new = X * V = U * S * V^T * V = U * S
+            U *= S[:self.n_components_]
 
-            logging.info("sklearn.decomposition.PCA.transform: " + method_uses_sklearn)
-            if self.whiten:
-                # X_new = X * V / S * sqrt(n_samples) = U * sqrt(n_samples)
-                U *= np.sqrt(X.shape[0] - 1)
-            else:
-                # X_new = X * V = U * S * V^T * V = U * S
-                U *= S[:self.n_components_]
-
-            return U
+        return U
 
     def transform(self, X):
         """Apply dimensionality reduction to X.
@@ -478,20 +472,19 @@ class PCA(PCA_original):
 
         X = check_array(X)
         if self.n_components_ > 0:
-            logging.info("sklearn.decomposition.PCA.transform: " + method_uses_daal)
+            logging.info("sklearn.decomposition.PCA.transform: " + get_patch_message("daal"))
             return self._transform_daal4py(X, whiten=self.whiten,
                                            check_X=False, scale_eigenvalues=False)
-        else:
-            logging.info("sklearn.decomposition.PCA.transform: " + method_uses_sklearn)
-            if self.mean_ is not None:
-                X = X - self.mean_
-                X_transformed = np.dot(X, self.components_.T)
-            if self.whiten:
-                X_transformed /= np.sqrt(self.explained_variance_)
-            return X_transformed
+        logging.info("sklearn.decomposition.PCA.transform: " + get_patch_message("sklearn"))
+        if self.mean_ is not None:
+            X = X - self.mean_
+        X_transformed = np.dot(X, self.components_.T)
+        if self.whiten:
+            X_transformed /= np.sqrt(self.explained_variance_)
+        return X_transformed
 
-if (lambda s: (int(s[:4]), int(s[6:])))( daal4py.__daal_link_version__[:8] ) < (2019, 4):
-    # with DAAL < 2019.4 PCA only optimizes fit, using DAAL's SVD
+if (lambda s: (int(s[:4]), int(s[6:])))( daal4py._get__daal_link_version__()[:8] ) < (2019, 4):
+    # 2019.4 PCA only optimizes fit, using DAAL's SVD
     class PCA(PCA_original):
         __doc__ = PCA_original.__doc__
 
@@ -507,4 +500,4 @@ if (lambda s: (int(s[:4]), int(s[6:])))( daal4py.__daal_link_version__[:8] ) < (
             self.random_state = random_state
 
         def _fit_full(self, X, n_components):
-            return _fit_full_copy(self, X, n_components)
+            return _fit_full_prev(self, X, n_components)
