@@ -20,10 +20,9 @@ import numbers
 import daal4py
 from scipy import sparse as sp
 from sklearn.utils import check_array, check_X_y
-from sklearn.linear_model._coordinate_descent import ElasticNet as ElasticNet_original
-from sklearn.linear_model._coordinate_descent import Lasso as Lasso_original
-from daal4py.sklearn._utils import (make2d, getFPType, method_uses_sklearn, \
-                        method_uses_daal, method_uses_sklearn_arter_daal)
+from sklearn.linear_model import ElasticNet as ElasticNet_original
+from sklearn.linear_model import Lasso as Lasso_original
+from daal4py.sklearn._utils import (make2d, getFPType, get_patch_message)
 import logging
 
 #only for compliance with Sklearn
@@ -68,7 +67,7 @@ def _daal4py_fit_enet(self, X, y_, check_input):
     y = make2d(y_)
     _fptype = getFPType(X)
 
-    #only for dual_gap computation, it is not required for DAAL
+    #only for dual_gap computation, it is not required for Intel(R) oneAPI Data Analytics Library
     self._X = X
     self._y = y
 
@@ -119,7 +118,7 @@ def _daal4py_fit_enet(self, X, y_, check_input):
         fptype = _fptype,
         method = 'defaultDense',
         selection = self.selection,
-        seed = 0 if (self.random_state == None) else self.random_state,
+        seed = 0 if (self.random_state is None) else self.random_state,
         nIterations = self.max_iter,
         positive = self.positive,
         accuracyThreshold = self.tol
@@ -211,7 +210,7 @@ def _daal4py_fit_lasso(self, X, y_, check_input):
     y = make2d(y_)
     _fptype = getFPType(X)
 
-    #only for dual_gap computation, it is not required for DAAL
+    #only for dual_gap computation, it is not required for Intel(R) oneAPI Data Analytics Library
     self._X = X
     self._y = y
 
@@ -255,7 +254,7 @@ def _daal4py_fit_lasso(self, X, y_, check_input):
         fptype = _fptype,
         method = 'defaultDense',
         selection = self.selection,
-        seed = 0 if (self.random_state == None) else self.random_state,
+        seed = 0 if (self.random_state is None) else self.random_state,
         nIterations = self.max_iter,
         positive = self.positive,
         accuracyThreshold = self.tol
@@ -351,22 +350,18 @@ class ElasticNet(ElasticNet_original):
             copy_X=copy_X, tol=tol, warm_start=warm_start,
             positive=positive, random_state=random_state, selection=selection)
 
-    def fit(self, X, y, sample_weight=None, check_input=True):
+    def fit(self, X, y, check_input=True):
         """Fit model with coordinate descent.
 
         Parameters
         ----------
-        X : {ndarray, sparse matrix} of (n_samples, n_features)
+        X : ndarray or scipy.sparse matrix, (n_samples, n_features)
             Data
 
-        y : {ndarray, sparse matrix} of shape (n_samples,) or \
-            (n_samples, n_targets)
+        y : ndarray, shape (n_samples,) or (n_samples, n_targets)
             Target. Will be cast to X's dtype if necessary
 
-        sample_weight : float or array-like of shape (n_samples,), default=None
-            Sample weight.
-
-        check_input : bool, default=True
+        check_input : boolean, (default=True)
             Allow to bypass several input checking.
             Don't use this parameter unless you know what you do.
 
@@ -385,7 +380,7 @@ class ElasticNet(ElasticNet_original):
             X, y = check_X_y(X, y, copy=False, accept_sparse='csc', dtype=[np.float64, np.float32], multi_output=True, y_numeric=True)
             y = check_array(y, copy=False, dtype=X.dtype.type, ensure_2d=False)
         else:
-            #only for compliance with Sklearn, this assert is not required for DAAL
+            #only for compliance with Sklearn, this assert is not required for Intel(R) oneAPI Data Analytics Library
             if (isinstance(X, np.ndarray) and X.flags['F_CONTIGUOUS'] == False):
                 raise ValueError("ndarray is not Fortran contiguous")
 
@@ -393,35 +388,33 @@ class ElasticNet(ElasticNet_original):
             self.fit_shape_good_for_daal_ = True if X.ndim <= 1 else True if X.shape[0] >= X.shape[1] else False   
         else:
             self.fit_shape_good_for_daal_ = False
+
         if (sp.issparse(X) or
-                sample_weight is not None or
                 not self.fit_shape_good_for_daal_ or
                 not (X.dtype == np.float64 or X.dtype == np.float32)):
-            logging.info("sklearn.linear_model.ElasticNet.fit: " + method_uses_sklearn)
             if hasattr(self, 'daal_model_'):
                 del self.daal_model_
-            res_new = super(ElasticNet, self).fit(X, y, sample_weight=sample_weight, check_input=check_input)
+            logging.info("sklearn.linear_model.ElasticNet.fit: " + get_patch_message("sklearn"))
+            res_new = super(ElasticNet, self).fit(X, y, check_input=check_input)
             self._gap = res_new.dual_gap_
             return res_new
-        else:
-            self.n_iter_ = None
-            self._gap = None
-            #only for pass tests "check_estimators_fit_returns_self(readonly_memmap=True) and check_regressors_train(readonly_memmap=True)
-            if  not (X.flags.writeable):
-                X = np.copy(X)
-            if  not (y.flags.writeable):
-                y = np.copy(y)
-            logging.info("sklearn.linear_model.ElasticNet.fit: " + method_uses_daal)
-            res = _daal4py_fit_enet(self, X, y, check_input=check_input)
-            if res is None:
-                if hasattr(self, 'daal_model_'):
-                    del self.daal_model_
-                logging.info("sklearn.linear_model.ElasticNet.fit: " + method_uses_sklearn_arter_daal)
-                res_new = super(ElasticNet, self).fit(X, y, sample_weight=sample_weight, check_input=check_input)
-                self._gap = res_new.dual_gap_
-                return res_new
-            else:
-                return res
+        self.n_iter_ = None
+        self._gap = None
+        #only for pass tests "check_estimators_fit_returns_self(readonly_memmap=True) and check_regressors_train(readonly_memmap=True)
+        if not (X.flags.writeable):
+            X = np.copy(X)
+        if not (y.flags.writeable):
+            y = np.copy(y)
+        logging.info("sklearn.linear_model.ElasticNet.fit: " + get_patch_message("daal"))
+        res = _daal4py_fit_enet(self, X, y, check_input=check_input)
+        if res is None:
+            if hasattr(self, 'daal_model_'):
+                del self.daal_model_
+            logging.info("sklearn.linear_model.ElasticNet.fit: " + get_patch_message("sklearn_after_daal"))
+            res_new = super(ElasticNet, self).fit(X, y, check_input=check_input)
+            self._gap = res_new.dual_gap_
+            return res_new
+        return res
 
 
     def predict(self, X):
@@ -445,11 +438,10 @@ class ElasticNet(ElasticNet_original):
                 sp.issparse(X) or
                 not good_shape_for_daal or
                 not (X.dtype == np.float64 or X.dtype == np.float32)):
-            logging.info("sklearn.linear_model.ElasticNet.predict: " + method_uses_sklearn)
+            logging.info("sklearn.linear_model.ElasticNet.predict: " + get_patch_message("sklearn"))
             return self._decision_function(X)
-        else:
-            logging.info("sklearn.linear_model.ElasticNet.predict: " + method_uses_daal)
-            return _daal4py_predict_enet(self, X)
+        logging.info("sklearn.linear_model.ElasticNet.predict: " + get_patch_message("daal"))
+        return _daal4py_predict_enet(self, X)
 
 
     @property
@@ -522,22 +514,18 @@ class Lasso(ElasticNet):
             positive=positive, random_state=random_state,
             selection=selection)
 
-    def fit(self, X, y, sample_weight=None, check_input=True):
+    def fit(self, X, y, check_input=True):
         """Fit model with coordinate descent.
 
         Parameters
         ----------
-        X : {ndarray, sparse matrix} of (n_samples, n_features)
+        X : ndarray or scipy.sparse matrix, (n_samples, n_features)
             Data
 
-        y : {ndarray, sparse matrix} of shape (n_samples,) or \
-            (n_samples, n_targets)
+        y : ndarray, shape (n_samples,) or (n_samples, n_targets)
             Target. Will be cast to X's dtype if necessary
 
-        sample_weight : float or array-like of shape (n_samples,), default=None
-            Sample weight.
-
-        check_input : bool, default=True
+        check_input : boolean, (default=True)
             Allow to bypass several input checking.
             Don't use this parameter unless you know what you do.
 
@@ -556,7 +544,8 @@ class Lasso(ElasticNet):
             X, y = check_X_y(X, y, copy=False, accept_sparse='csc', dtype=[np.float64, np.float32], multi_output=True, y_numeric=True)
             y = check_array(y, copy=False, dtype=X.dtype.type, ensure_2d=False)
         else:
-            #only for compliance with Sklearn, this assert is not required for DAAL
+            #only for compliance with Sklearn, this assert is not required for Intel(R) oneAPI Data
+            #Analytics Library
             if (isinstance(X, np.ndarray) and X.flags['F_CONTIGUOUS'] == False):
                 raise ValueError("ndarray is not Fortran contiguous")
 
@@ -566,34 +555,31 @@ class Lasso(ElasticNet):
             self.fit_shape_good_for_daal_ = False
 
         if (sp.issparse(X) or
-                sample_weight is not None or
                 not self.fit_shape_good_for_daal_ or
                 not (X.dtype == np.float64 or X.dtype == np.float32)):
             if hasattr(self, 'daal_model_'):
                 del self.daal_model_
-            logging.info("sklearn.linear_model.Lasso.fit: " + method_uses_sklearn)
-            res_new = super(ElasticNet, self).fit(X, y, sample_weight=sample_weight, check_input=check_input)
+            logging.info("sklearn.linear_model.Lasso.fit: " + get_patch_message("sklearn"))
+            res_new = super(ElasticNet, self).fit(X, y, check_input=check_input)
             self._gap = res_new.dual_gap_
             return res_new
-        else:
-            self.n_iter_ = None
-            self._gap = None
-            #only for pass tests "check_estimators_fit_returns_self(readonly_memmap=True) and check_regressors_train(readonly_memmap=True)
-            if  not (X.flags.writeable):
-                X = np.copy(X)
-            if  not (y.flags.writeable):
-                y = np.copy(y)
-            logging.info("sklearn.linear_model.Lasso.fit: " + method_uses_daal)
-            res = _daal4py_fit_lasso(self, X, y, check_input=check_input)
-            if res is None:
-                if hasattr(self, 'daal_model_'):
-                    del self.daal_model_
-                logging.info("sklearn.linear_model.Lasso.fit: " + method_uses_sklearn_arter_daal)
-                res_new = super(ElasticNet, self).fit(X, y, sample_weight=sample_weight, check_input=check_input)
-                self._gap = res_new.dual_gap_
-                return res_new
-            else:
-                return res
+        self.n_iter_ = None
+        self._gap = None
+        #only for pass tests "check_estimators_fit_returns_self(readonly_memmap=True) and check_regressors_train(readonly_memmap=True)
+        if  not (X.flags.writeable):
+            X = np.copy(X)
+        if  not (y.flags.writeable):
+            y = np.copy(y)
+        logging.info("sklearn.linear_model.Lasso.fit: " + get_patch_message("daal"))
+        res = _daal4py_fit_lasso(self, X, y, check_input=check_input)
+        if res is None:
+            if hasattr(self, 'daal_model_'):
+                del self.daal_model_
+            logging.info("sklearn.linear_model.Lasso.fit: " + get_patch_message("sklearn_after_daal"))
+            res_new = super(ElasticNet, self).fit(X, y, check_input=check_input)
+            self._gap = res_new.dual_gap_
+            return res_new
+        return res
 
 
     def predict(self, X):
@@ -609,7 +595,6 @@ class Lasso(ElasticNet):
         C : array, shape = (n_samples,)
             Returns predicted values.
         """
-
         X = check_array(X, accept_sparse=['csr', 'csc', 'coo'])
         good_shape_for_daal = True if X.ndim <= 1 else True if X.shape[0] >= X.shape[1] else False
 
@@ -617,8 +602,7 @@ class Lasso(ElasticNet):
                 sp.issparse(X) or
                 not good_shape_for_daal or
                 not (X.dtype == np.float64 or X.dtype == np.float32)):
-            logging.info("sklearn.linear_model.Lasso.predict: " + method_uses_sklearn)
+            logging.info("sklearn.linear_model.Lasso.predict: " + get_patch_message("sklearn"))
             return self._decision_function(X)
-        else:
-            logging.info("sklearn.linear_model.Lasso.predict: " + method_uses_daal)
-            return _daal4py_predict_lasso(self, X)
+        logging.info("sklearn.linear_model.Lasso.predict: " + get_patch_message("daal"))
+        return _daal4py_predict_lasso(self, X)
